.. _profile_detect:

**detect** - Create a profile from a MPI library
================================================

Usage
--------

.. code::

    e4s-cl profile detect [ OPTIONS ] < MPI launcher command >

Options
-------

-p, --profile   The profile in which the gathered information will be output

Description
------------

.. automodule:: e4s_cl.cli.commands.profile.detect
